from __future__ import annotations
from typing import Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
	from entity import Entity

class Inventory:
	"""Handles inventory for an Entity"""
	_contents: Set[Entity]

	def __init__(self, contents: Set[Entity] = set()):
		self._contents = contents

	def insert(self, entity: Entity) -> bool:
		if entity in self._contents:
			return False

		self._contents.add(entity)
		return True

	def access(self, key: str) -> Optional[Entity]:
		return self._contents[key]

	def remove(self, key: str) -> Optional[Entity]:
		item = self._contents[key]
		self._contents.remove(key)
		return item

	@property
	def contents(self) -> Set[Entity]:
		return self._contents
