from __future__ import annotations
from typing import TYPE_CHECKING

from tcod.console import Console

import colors

if TYPE_CHECKING:
	from engine import Engine
	from floor_map import FloorMap

#utils
def get_names_at(x: int, y: int, floor_map: FloorMap) -> str:
	if not floor_map.in_bounds(x, y) or not floor_map.visible[x, y]:
		return ""

	names = ", ".join(
		entity.name for entity in floor_map.entities if entity.x == x and entity.y == y
	)

	return names

#direct rendering functions
def render_hp_bar(console: Console, x: int, y: int, current_value: int, max_value: int, total_width: int) -> None:
	bar_width = int(float(current_value) / max_value * total_width)

	console.draw_rect(x=x, y=y, width=total_width, height=1, ch=1, bg=colors.terminal_dark)

	if bar_width > 0:
		console.draw_rect(x=x, y=y, width=bar_width, height=1, ch=1, bg=colors.green)

	console.print(x=x + 1, y=y, string=f"HP: {current_value}/{max_value}", fg=colors.white)

def render_names_at(console: Console, x: int, y: int, engine: Engine) -> None:
	mouse_x, mouse_y = engine.mouse_position

	names: str = get_names_at(mouse_x, mouse_y, engine.floor_map)

	console.print(x=x, y=y, string=names)
